@@ -16,7 +16,7 @@ class PredicateParser(StandardParser):
     * Infix predicate formuale must come without outer parentheses, e.g. ``"(a = b)"`` is not well formed
     * Outermost parentheses in infix function terms can be ommited, e.g. both ``"0+(0+0)"`` and ``"(0+(0+0))"`` are ok
     * Infix predicates and function symbols CANNOT be given in prefix notation
-    * Quantified formulae come in format ∀x (A) or ∀x ∈ T (A) - Always add parentheses to the quantified formula
+    * Quantified formulae come in format ∀x A or ∀x ∈ T A - Do not add extra parentheses to the quantified formula
 
     Parameters
     ----------
@@ -44,31 +44,31 @@ class PredicateParser(StandardParser):
     >>> from logics.instances.predicate.languages import real_number_arithmetic_language
     >>> from logics.utils.parsers.predicate_parser import PredicateParser
     >>> replacement_dict = {
-    ...                         '¬': '~', 'not ': '~',
-    ...                         '&': '∧', ' and ': '∧',  # notice the spaces before and after 'and'
-    ...                         'v': '∨',  ' or ': '∨',
-    ...                         ' then ': '→', '-->': '→', 'if ': '',  # 'if p then q' it will convert to 'p then q'
-    ...                         ' iff ': '↔', '<->': '↔',
-    ...                         'forall ': '∀', 'exists ': '∃', ' in ': '∈'
-    ...                     }
+    ...     '¬': '~', 'not ': '~',
+    ...     '&': '∧', ' and ': '∧',  # notice the spaces before and after 'and'
+    ...     'v': '∨',  ' or ': '∨',
+    ...     ' then ': '→', '-->': '→', 'if ': '',  # 'if p then q' it will convert to 'p then q'
+    ...     ' iff ': '↔', '<->': '↔',
+    ...     'forall ': '∀', 'exists ': '∃', ' in ': '∈'
+    ... }
     >>> real_number_arithmetic_parser = PredicateParser(language=real_number_arithmetic_language,
     ...                                                 parse_replacement_dict=replacement_dict,
     ...                                                 infix_cts=['∧', '∨', '→', '↔'],
     ...                                                 infix_pred=['=', '<', '>'], infix_func=['+', '*', '**'])
     >>> real_number_arithmetic_parser.parse("0.5 + 0.5 = 1")
     ['=', ('+', '0.5', '0.5'), '1']
-    >>> f = real_number_arithmetic_parser.parse("1 + 1 = 2 or exists x (x + 1 = 2)")
+    >>> f = real_number_arithmetic_parser.parse("1 + 1 = 2 or exists x x + 1 = 2")
     >>> f
     ['∨', ['=', ('+', '1', '1'), '2'], ['∃', 'x', ['=', ('+', 'x', '1'), '2']]]
     >>> type(f)
     <class 'logics.classes.predicate.formula.PredicateFormula'>
     >>> real_number_arithmetic_parser.unparse(f)
-    '1 + 1 = 2 ∨ ∃x (x + 1 = 2)'
+    '1 + 1 = 2 ∨ ∃x x + 1 = 2'
     >>> # Infix predicates and function symbols cannot be given in prefix notation
     >>> real_number_arithmetic_parser.parse("=(+(1,1),2)")
     Traceback (most recent call last):
     ...
-    IndexError: string index out of range
+    logics.classes.exceptions.NotWellFormed: String  is not a valid term
 
     Examples with a predefined parser for a language with prefix predicates and function symbols (see below for
     more predefined instances):
@@ -76,6 +76,8 @@ class PredicateParser(StandardParser):
     >>> from logics.utils.parsers.predicate_parser import classical_predicate_parser
     >>> classical_predicate_parser.parse("R(a, b) or P(f(a))")
     ['∨', ['R', 'a', 'b'], ['P', ('f', 'a')]]
+    >>> classical_predicate_parser.parse("forall x ~P(x)")
+    ['∀', 'x', ['~', ['P', 'x']]]
     >>> classical_predicate_parser.parse("forall x in f(a) (if ~P(x) then P(x))")
     ['∀', 'x', '∈', ('f', 'a'), ['→', ['~', ['P', 'x']], ['P', 'x']]]
     """
@@ -183,6 +185,8 @@ class PredicateParser(StandardParser):
         raise NotWellFormed(f'String {string} is not a valid term')
 
     def _parse_infix_term(self, string):
+        if not string:
+            return None
         # If not between parentheses, its something of the form 's(0+0)' and not '(0+0)'
         if string[0] != '(' or string[-1] != ')':
             return None
@@ -212,20 +216,23 @@ class PredicateParser(StandardParser):
 
                 # See if the quantifier is bounded and parse the bound
                 bounded = False
-                formula_opening_parenthesis_index = parser_utils.get_last_opening_parenthesis(string)
-                if formula_opening_parenthesis_index is None:
-                    raise NotWellFormed(f'Quantified formula in {string} must come between parentheses')
-                elif string[current_index] == '∈':
+                if string[current_index] == '∈':
                     bounded = True
                     current_index += 1
-                    unparsed_term = string[current_index:formula_opening_parenthesis_index]
-                    parsed_term = self.parse_term(unparsed_term, replace=False)
-                # We have a non bounded-formula, the parenthesis must come immediately after the variable
-                elif formula_opening_parenthesis_index != current_index:
-                    raise NotWellFormed(f'Quantified formula in {string} must come between parentheses')
+                    bound_endind_index = None
+                    for char_index in range(current_index+1, len(string)):
+                        try:
+                            parsed_term = self.parse_term(string[current_index:char_index], replace=False)
+                            bound_endind_index = char_index - 1
+                        except NotWellFormed:
+                            pass
+                    if bound_endind_index is None:
+                        raise NotWellFormed("Incorrect bound for a quantifier")
+                    else:
+                        current_index = bound_endind_index + 1
 
                 # Lastly, parse the formula
-                unparsed_formula = string[formula_opening_parenthesis_index+1:-1]
+                unparsed_formula = string[current_index:]
                 parsed_formula = self.parse(unparsed_formula)
 
                 if not bounded:
@@ -275,9 +282,10 @@ class PredicateParser(StandardParser):
         if formula.main_symbol in self.language.quantifiers:
             # Bounded
             if formula[2] == '∈':
-                return f'{formula[0]}{formula[1]} ∈ {self._unparse_term(formula[3])} ({self._unparse_formula(formula[4], remove_external_parentheses=True)})'
+                return f'{formula[0]}{formula[1]} ∈ {self._unparse_term(formula[3])} ' \
+                       f'{self._unparse_formula(formula[4], remove_external_parentheses=False)}'
             # Unbounded
-            return f'{formula[0]}{formula[1]} ({self._unparse_formula(formula[2], remove_external_parentheses=True)})'
+            return f'{formula[0]}{formula[1]} {self._unparse_formula(formula[2], remove_external_parentheses=False)}'
 
         # Non-quantified formula
         return super()._unparse_molecular(formula, remove_external_parentheses)
@@ -307,13 +315,13 @@ class ArithmeticTruthParser(PredicateParser):
     >>> from logics.utils.parsers.parser_utils import godel_encode, godel_decode
     >>> from logics.utils.parsers.predicate_parser import ArithmeticTruthParser
     >>> replacement_dict = {
-    ...                         '¬': '~', 'not ': '~',
-    ...                         '&': '∧', ' and ': '∧',  # notice the spaces before and after 'and'
-    ...                         'v': '∨',  ' or ': '∨',
-    ...                         ' then ': '→', '-->': '→', 'if ': '',  # 'if p then q' it will convert to 'p then q'
-    ...                         ' iff ': '↔', '<->': '↔',
-    ...                         'forall ': '∀', 'exists ': '∃', ' in ': '∈'
-    ...                     }
+    ...     '¬': '~', 'not ': '~',
+    ...     '&': '∧', ' and ': '∧',  # notice the spaces before and after 'and'
+    ...     'v': '∨',  ' or ': '∨',
+    ...     ' then ': '→', '-->': '→', 'if ': '',  # 'if p then q' it will convert to 'p then q'
+    ...     ' iff ': '↔', '<->': '↔',
+    ...     'forall ': '∀', 'exists ': '∃', ' in ': '∈'
+    ... }
     >>> replacement_dict.update({
     ...     '⌜': 'quote(',
     ...     '⌝': ')'
